@@ -71,21 +71,17 @@ def _link_jupyter_server_extension(serverapp):
     # to incorporate a dependency injection system in the
     # Extension manager that allows extensions to list
     # their dependency tree and sort that way.
-    def extensions(self):
+    def sorted_extensions(self):
         """Dictionary with extension package names as keys
         and an ExtensionPackage objects as values.
         """
-        # Pop out the nbclassic extension to prepend
-        # this extension at the front of the sorted server extensions.
-        nb = self._extensions.get("nbclassic")
-        # Sort all other extensions alphabetically.
-        other_extensions = dict(sorted(self._extensions.items()))
-        # Build a new extensions dictionary, sorted with nbclassic first.
-        sorted_extensions = {"nbclassic": nb}
-        sorted_extensions.update(**other_extensions)
-        return sorted_extensions
+        # Sort the keys and
+        keys = sorted(self.extensions.keys())
+        keys.remove("nbclassic")
+        keys = ["nbclassic"] + keys
+        return {key: self.extensions[key] for key in keys}
 
-    manager.__class__.extensions = property(extensions)
+    manager.__class__.sorted_extensions = property(sorted_extensions)
 
     # Look to see if nbclassic is enabled. if so,
     # link the nbclassic extension here to load
@@ -123,7 +119,7 @@ def _link_jupyter_server_extension(serverapp):
                     "Consider moving the extension to Jupyter Server's "
                     "extension paths.".format(name=name)
                 )
-                manager.link_extension(name, serverapp)
+                manager.link_extension(name)
 
 
 def _load_jupyter_server_extension(serverapp):
